import type { Env } from "../types.js";
import { authenticateUserFunction, createUserFunction, deleteUserFunction, getUserFunction, getUserByProviderIdFunction, updateUserAttributesFunction, updateUserPasswordFunction, updateUserProviderIdFunction, getSessionUserFunction } from "./user/index.js";
import { parseRequestFunction, validateRequestFunction, getSessionUserFromRequestFunction } from "./request.js";
import { createSessionFunction, deleteDeadUserSessionsFunction, renewSessionFunction, invalidateAllUserSessionsFunction, validateSessionFunction, invalidateSessionFunction, generateSessionIdFunction } from "./session.js";
import { createSessionCookiesFunction } from "./cookie.js";
import { Adapter, SessionAdapter, UserAdapter, UserData, UserSchema } from "../types.js";
export declare const lucia: <C extends Configurations>(configs: C) => Omit<Auth<C>, "getAuthSession">;
export declare class Auth<C extends Configurations = any> {
    configs: UserConfig<C>;
    constructor(configs: C);
    getUser: ReturnType<typeof getUserFunction>;
    getUserByProviderId: ReturnType<typeof getUserByProviderIdFunction>;
    getSessionUser: ReturnType<typeof getSessionUserFunction>;
    createUser: ReturnType<typeof createUserFunction>;
    updateUserAttributes: ReturnType<typeof updateUserAttributesFunction>;
    updateUserProviderId: ReturnType<typeof updateUserProviderIdFunction>;
    updateUserPassword: ReturnType<typeof updateUserPasswordFunction>;
    deleteUser: ReturnType<typeof deleteUserFunction>;
    authenticateUser: ReturnType<typeof authenticateUserFunction>;
    validateSession: ReturnType<typeof validateSessionFunction>;
    generateSessionId: ReturnType<typeof generateSessionIdFunction>;
    createSession: ReturnType<typeof createSessionFunction>;
    renewSession: ReturnType<typeof renewSessionFunction>;
    invalidateSession: ReturnType<typeof invalidateSessionFunction>;
    invalidateAllUserSessions: ReturnType<typeof invalidateAllUserSessionsFunction>;
    deleteDeadUserSessions: ReturnType<typeof deleteDeadUserSessionsFunction>;
    parseRequest: ReturnType<typeof parseRequestFunction>;
    validateRequest: ReturnType<typeof validateRequestFunction>;
    getSessionUserFromRequest: ReturnType<typeof getSessionUserFromRequestFunction>;
    createSessionCookies: ReturnType<typeof createSessionCookiesFunction>;
}
interface Configurations {
    adapter: Adapter | {
        user: UserAdapter;
        session: SessionAdapter;
    };
    env: Env;
    generateCustomUserId?: () => Promise<string | null>;
    csrfProtection?: boolean;
    sessionTimeout?: number;
    idlePeriodTimeout?: number;
    transformUserData?: (userData: UserData) => Record<string, any>;
    sessionCookieOptions?: CookieOption[];
    deleteCookieOptions?: CookieOption[];
}
declare type CookieOption = {
    sameSite?: "strict" | "lax";
    path?: string;
    domain?: string;
};
declare type UserConfig<C extends Configurations = any> = {
    adapter: Adapter;
    env: Env;
    generateCustomUserId: () => Promise<string | null>;
    csrfProtection: boolean;
    sessionTimeout: number;
    idlePeriodTimeout: number;
    sessionCookieOptions: CookieOption[];
    deleteCookieOptions: CookieOption[];
    transformUserData: (userData: UserSchema) => C["transformUserData"] extends {} ? ReturnType<C["transformUserData"]> : {
        userId: string;
    };
};
export {};
