import type { LuciaError } from "./error.js";
export type { Auth } from "./auth/index.js";
export declare type User = ReturnType<Lucia.Auth["configs"]["transformUserData"]>;
export declare type Session = {
    sessionId: string;
    userId: string;
    expires: number;
    idlePeriodExpires: number;
};
export declare type Env = "DEV" | "PROD";
export declare type Error = typeof LuciaError;
export declare type UserSchema = {
    id: string;
    hashed_password: string | null;
    provider_id: string;
} & Lucia.UserAttributes;
export declare type UserData = {
    id: string;
} & Required<Lucia.UserAttributes>;
export declare type SessionSchema = {
    id: string;
    expires: number;
    idle_expires: number;
    user_id: string;
};
export declare type Adapter = {
    getSessionAndUserBySessionId?: (sessionId: string) => Promise<{
        user: UserSchema;
        session: SessionSchema;
    } | null>;
} & SessionAdapter & UserAdapter;
export declare type UserAdapter = {
    getUser: (userId: string) => Promise<UserSchema | null>;
    getUserByProviderId: (providerId: string) => Promise<UserSchema | null>;
    setUser: (userId: string | null, data: {
        providerId: string;
        hashedPassword: string | null;
        attributes: Record<string, any>;
    }) => Promise<UserSchema>;
    deleteUser: (userId: string) => Promise<void>;
    updateUser: (userId: string, data: {
        providerId?: string | null;
        hashedPassword?: string | null;
        attributes?: Record<string, any>;
    }) => Promise<UserSchema>;
};
export declare type SessionAdapter = {
    getSession: (sessionId: string) => Promise<SessionSchema | null>;
    getSessionsByUserId: (userId: string) => Promise<SessionSchema[]>;
    setSession: (sessionId: string, data: {
        userId: string;
        expires: number;
        idlePeriodExpires: number;
    }) => Promise<void>;
    deleteSession: (...sessionIds: string[]) => Promise<void>;
    deleteSessionsByUserId: (userId: string) => Promise<void>;
};
export declare type MinimalRequest = {
    headers: {
        get: (name: string) => null | string;
    };
    url: string;
    method: string;
};
